@@ -1,6 +1,5 @@
 from __future__ import absolute_import
 
-
 from sentry_sdk._compat import iteritems
 from sentry_sdk._types import MYPY
 from sentry_sdk.hub import Hub, _should_send_default_pii
@@ -41,6 +40,12 @@ except ImportError:
     # Startlette 0.19.1
     from starlette.exceptions import ExceptionMiddleware  # type: ignore
 
+try:
+    # Optional dependency of Starlette to parse form data.
+    import multipart  # type: ignore # noqa: F401
+except ImportError:
+    multipart = None
+
 
 _DEFAULT_TRANSACTION_NAME = "generic Starlette request"
 
@@ -339,6 +344,9 @@ class StarletteRequestExtractor:
         curl -X POST http://localhost:8000/upload/somethign -H "Content-Type: application/x-www-form-urlencoded" -d "username=kevin&password=welcome123"
         curl -X POST http://localhost:8000/upload/somethign  -F username=Julian -F password=hello123
         """
+        if multipart is None:
+            return None
+
         return await self.request.form()
 
     def is_json(self):
@@ -423,6 +431,7 @@ class SentryStarletteMiddleware:
         hub = Hub.current
         integration = hub.get_integration(StarletteIntegration)
         if integration is None:
+            await self.app(scope, receive, send)
             return
 
         with hub.configure_scope() as sentry_scope:
